forney_algorithm

Function forney_algorithm 

pub fn forney_algorithm(
    omega: &PolyGF256,
    sigma: &PolyGF256,
    error_locs: &[u8],
) -> Result<Vec<u8>, String>
Computes error magnitudes using Forney’s algorithm.

Arguments

  • omega - The error evaluator polynomial.
  • sigma - The error locator polynomial.
  • error_locs - The positions of errors in the codeword.

Returns

A vector of error magnitudes for each error location.

Errors

Returns an error if division by zero occurs during magnitude calculation.