plot_vector_field_3d

Function plot_vector_field_3d 

pub fn plot_vector_field_3d(
    comps: (&Expr, &Expr, &Expr),
    vars: (&str, &str, &str),
    ranges: ((f64, f64), (f64, f64), (f64, f64)),
    path: &str,
    config: Option<PlotConfig>,
) -> Result<(), String>
Plots a 3D vector field and saves it to a file.

Errors

This function will return an error if the plot cannot be created or saved.