Module manager

Module manager 

Plugin manager for loading and managing plugins.

Plugin Manager

Responsible for loading, managing, and interacting with plugins.

Structs

ManagedPlugin
Holds the plugin instance and its current health state.
ManagedStablePlugin
A plugin that is managed by the plugin manager.
PluginManager
Manages the lifecycle of all loaded plugins.

Statics

GLOBAL_PLUGIN_MANAGER
Global instance of the PluginManager for FFI access.