LinearProgramState

Struct LinearProgramState 

pub struct LinearProgramState<P, F> {
Show 16 fields pub param: Option<P>, pub prev_param: Option<P>, pub best_param: Option<P>, pub prev_best_param: Option<P>, pub cost: F, pub prev_cost: F, pub best_cost: F, pub prev_best_cost: F, pub target_cost: F, pub iter: u64, pub last_best_iter: u64, pub max_iters: u64, pub counts: HashMap<String, u64>, pub counting_enabled: bool, pub time: Option<Duration>, pub termination_status: TerminationStatus,
}
Maintains the state from iteration to iteration of a solver

This struct is passed from one iteration of an algorithm to the next.

Keeps track of

  • parameter vector of current and previous iteration
  • best parameter vector of current and previous iteration
  • cost function value of current and previous iteration
  • current and previous best cost function value
  • target cost function value
  • current iteration number
  • iteration number where the last best parameter vector was found
  • maximum number of iterations that will be executed
  • problem function evaluation counts (cost function, gradient, jacobian, hessian,
  • elapsed time
  • termination status

Fields

param: Option<P>

Current parameter vector

prev_param: Option<P>

Previous parameter vector

best_param: Option<P>

Current best parameter vector

prev_best_param: Option<P>

Previous best parameter vector

cost: F

Current cost function value

prev_cost: F

Previous cost function value

best_cost: F

Current best cost function value

prev_best_cost: F

Previous best cost function value

target_cost: F

Target cost function value

iter: u64

Current iteration

last_best_iter: u64

Iteration number of last best cost

max_iters: u64

Maximum number of iterations

counts: HashMap<String, u64>

Evaluation counts

counting_enabled: bool

Update evaluation counts?

time: Option<Duration>

Time required so far

termination_status: TerminationStatus

Status of optimization execution

Implementations

Source

impl<P, F> LinearProgramState<P, F>

pub fn param(self, param: P) -> LinearProgramState<P, F>

Set parameter vector. This shifts the stored parameter vector to the previous parameter vector.

Example
let state = state.param(param);
pub fn target_cost(self, target_cost: F) -> LinearProgramState<P, F>

Set target cost.

When this cost is reached, the algorithm will stop. The default is Self::Float::NEG_INFINITY.

Example
let state = state.target_cost(0.0);
pub fn max_iters(self, iters: u64) -> LinearProgramState<P, F>

Set maximum number of iterations

Example
let state = state.max_iters(1000);
pub fn cost(self, cost: F) -> LinearProgramState<P, F>

Set the current cost function value. This shifts the stored cost function value to the previous cost function value.

Example
let state = state.cost(cost);
pub fn counting(self, mode: bool) -> LinearProgramState<P, F>

Overrides state of counting function executions (default: false)

let state = state.counting(true);