pub struct TestSparseProblem {}Expand description
A struct representing the following sparse problem.
Example 1: x = [1, 1, 0, 0], y = 1 Example 2: x = [0, 0, 1, 1], y = -1 Example 3: x = [1, 0, 0, 0], y = 1 Example 4: x = [0, 0, 1, 0], y = -1
cost = Σ (w^T x - y)^2
Implements CostFunction and Gradient.
Implementations
Sourceimpl TestSparseProblem
impl TestSparseProblem
Sourcepub fn new() -> TestSparseProblem
pub fn new() -> TestSparseProblem
Create an instance of TestSparseProblem.
Example
use argmin::core::test_utils::TestSparseProblem;
let problem = TestSparseProblem::new();Trait Implementations
Sourceimpl Clone for TestSparseProblem
impl Clone for TestSparseProblem
Sourcefn clone(&self) -> TestSparseProblem
fn clone(&self) -> TestSparseProblem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CostFunction for TestSparseProblem
impl CostFunction for TestSparseProblem
Sourcefn cost(
&self,
param: &<TestSparseProblem as CostFunction>::Param,
) -> Result<<TestSparseProblem as CostFunction>::Output, Error>
fn cost( &self, param: &<TestSparseProblem as CostFunction>::Param, ) -> Result<<TestSparseProblem as CostFunction>::Output, Error>
Returns a sum of squared errors.
Example
use argmin::core::test_utils::TestSparseProblem;
use argmin::core::CostFunction;
let problem = TestSparseProblem::new();
let param = vec![1.0, 2.0, 3.0, 4.0];
let res = problem.cost(¶m)?;Sourcefn bulk_cost<P>(&self, params: &[P]) -> Result<Vec<Self::Output>, Error>
fn bulk_cost<P>(&self, params: &[P]) -> Result<Vec<Self::Output>, Error>
Compute
cost in bulk. If the rayon feature is enabled, multiple calls to cost will be run in parallel using rayon, otherwise they will execute sequentially. If the rayon feature is enabled, parallelization can still be turned off by overwriting parallelize to return false. This can be useful in cases where it is preferable to parallelize only certain parts. Note that even if parallelize is set to false, the parameter vectors and the problem are still required to be Send and Sync. Those bounds are linked to the rayon feature. This method can be overwritten.Sourcefn parallelize(&self) -> bool
fn parallelize(&self) -> bool
Indicates whether to parallelize calls to
cost when using bulk_cost. By default returns true, but can be set manually to false if needed. This allows users to turn off parallelization for certain traits implemented on their problem. Note that parallelization requires the rayon feature to be enabled, otherwise calls to cost will be executed sequentially independent of how parallelize is set.Sourceimpl Debug for TestSparseProblem
impl Debug for TestSparseProblem
Sourceimpl Default for TestSparseProblem
impl Default for TestSparseProblem
Sourcefn default() -> TestSparseProblem
fn default() -> TestSparseProblem
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TestSparseProblem
impl<'de> Deserialize<'de> for TestSparseProblem
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TestSparseProblem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TestSparseProblem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Gradient for TestSparseProblem
impl Gradient for TestSparseProblem
Sourcefn gradient(
&self,
param: &<TestSparseProblem as Gradient>::Param,
) -> Result<<TestSparseProblem as Gradient>::Gradient, Error>
fn gradient( &self, param: &<TestSparseProblem as Gradient>::Param, ) -> Result<<TestSparseProblem as Gradient>::Gradient, Error>
Returns a gradient of the cost function.
Example
use argmin::core::test_utils::TestSparseProblem;
use argmin::core::Gradient;
let problem = TestSparseProblem::new();
let param = vec![1.0, 2.0, 3.0, 4.0];
let res = problem.gradient(¶m)?;Sourcefn bulk_gradient<P>(&self, params: &[P]) -> Result<Vec<Self::Gradient>, Error>
fn bulk_gradient<P>(&self, params: &[P]) -> Result<Vec<Self::Gradient>, Error>
Compute
gradient in bulk. If the rayon feature is enabled, multiple calls to gradient will be run in parallel using rayon, otherwise they will execute sequentially. If the rayon feature is enabled, parallelization can still be turned off by overwriting parallelize to return false. This can be useful in cases where it is preferable to parallelize only certain parts. Note that even if parallelize is set to false, the parameter vectors and the problem are still required to be Send and Sync. Those bounds are linked to the rayon feature. This method can be overwritten.Sourcefn parallelize(&self) -> bool
fn parallelize(&self) -> bool
Indicates whether to parallelize calls to
gradient when using bulk_gradient. By default returns true, but can be set manually to false if needed. This allows users to turn off parallelization for certain traits implemented on their problem. Note that parallelization requires the rayon feature to be enabled, otherwise calls to gradient will be executed sequentially independent of how parallelize is set.Sourceimpl Hash for TestSparseProblem
impl Hash for TestSparseProblem
Sourceimpl PartialEq for TestSparseProblem
impl PartialEq for TestSparseProblem
Sourceimpl Serialize for TestSparseProblem
impl Serialize for TestSparseProblem
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for TestSparseProblem
impl Eq for TestSparseProblem
impl StructuralPartialEq for TestSparseProblem