pub struct UnpodStack<'a> { /* private fields */ }Expand description
Owns an unsized array of data, allocated from some stack.
Methods from Deref<Target = MemStack>
Sourcepub fn can_hold(&self, alloc_req: StackReq) -> bool
pub fn can_hold(&self, alloc_req: StackReq) -> bool
Returns true if the stack can hold an allocation with the given size and alignment
requirements.
Sourcepub fn as_ptr(&self) -> *const u8
pub fn as_ptr(&self) -> *const u8
Returns a pointer to the (possibly uninitialized) stack memory.
Sourcepub fn make_aligned_uninit<T>(
&mut self,
size: usize,
align: usize,
) -> (&mut [MaybeUninit<T>], &mut MemStack)
pub fn make_aligned_uninit<T>( &mut self, size: usize, align: usize, ) -> (&mut [MaybeUninit<T>], &mut MemStack)
Sourcepub fn make_aligned_with<T>(
&mut self,
size: usize,
align: usize,
f: impl FnMut(usize) -> T,
) -> (DynArray<'_, T>, &mut MemStack)
pub fn make_aligned_with<T>( &mut self, size: usize, align: usize, f: impl FnMut(usize) -> T, ) -> (DynArray<'_, T>, &mut MemStack)
Sourcepub fn make_uninit<T>(
&mut self,
size: usize,
) -> (&mut [MaybeUninit<T>], &mut MemStack)
pub fn make_uninit<T>( &mut self, size: usize, ) -> (&mut [MaybeUninit<T>], &mut MemStack)
Sourcepub fn make_with<T>(
&mut self,
size: usize,
f: impl FnMut(usize) -> T,
) -> (DynArray<'_, T>, &mut MemStack)
pub fn make_with<T>( &mut self, size: usize, f: impl FnMut(usize) -> T, ) -> (DynArray<'_, T>, &mut MemStack)
Sourcepub fn collect_aligned<I>(
&mut self,
align: usize,
iter: impl IntoIterator<Item = I>,
) -> (DynArray<'_, I>, &mut MemStack)
pub fn collect_aligned<I>( &mut self, align: usize, iter: impl IntoIterator<Item = I>, ) -> (DynArray<'_, I>, &mut MemStack)
Returns a new aligned DynArray, initialized with the provided iterator, and a stack
over the remainder of the buffer.
If there isn’t enough space for all the iterator items, then the returned array only
contains the first elements that fit into the stack.
Panics
Panics if the provided iterator panics.
Sourcepub fn collect<I>(
&mut self,
iter: impl IntoIterator<Item = I>,
) -> (DynArray<'_, I>, &mut MemStack)
pub fn collect<I>( &mut self, iter: impl IntoIterator<Item = I>, ) -> (DynArray<'_, I>, &mut MemStack)
pub fn bump<'bump, 'stack>( self: &'bump mut &'stack mut MemStack, ) -> &'bump mut Bump<'stack>