RangeFrom

Struct RangeFrom 

1.96.0 · Source
pub struct RangeFrom<Idx> {
    pub start: Idx,
}
A range only bounded inclusively below.

The RangeFrom contains all values with x >= start.

Note: Overflow in the IntoIterator implementation (when the contained data type reaches its numerical limit) is allowed to panic, wrap, or saturate. This behavior is defined by the implementation of the Step trait. For primitive integers, this follows the normal rules, and respects the overflow checks profile (panic in debug, wrap in release). Unlike its legacy counterpart, the iterator will only panic after yielding the maximum value when overflow checks are enabled.

Examples

use core::range::RangeFrom;

assert_eq!(RangeFrom::from(2..), core::range::RangeFrom { start: 2 });
assert_eq!(2 + 3 + 4, RangeFrom::from(2..).into_iter().take(3).sum());

Edition notes

It is planned that the syntax start.. will construct this type in a future edition, but it does not do so today.

Fields

start: Idx

The lower bound of the range (inclusive).

Implementations

Source

impl<Idx> RangeFrom<Idx>
where Idx: Step,

1.96.0 · Source

pub fn iter(&self) -> RangeFromIter<Idx>

Creates an iterator over the elements within this range.

Shorthand for .clone().into_iter()

Examples
use core::range::RangeFrom;

let mut i = RangeFrom::from(3..).iter().map(|n| n*n);
assert_eq!(i.next(), Some(9));
assert_eq!(i.next(), Some(16));
assert_eq!(i.next(), Some(25));
Source

impl<Idx> RangeFrom<Idx>
where Idx: PartialOrd,

1.96.0 (const: unstable) · Source

pub fn contains<U>(&self, item: &U) -> bool
where Idx: PartialOrd<U>, U: PartialOrd<Idx> + ?Sized,

Returns true if item is contained in the range.

Examples
use core::range::RangeFrom;

assert!(!RangeFrom::from(3..).contains(&2));
assert!( RangeFrom::from(3..).contains(&3));
assert!( RangeFrom::from(3..).contains(&1_000_000_000));

assert!( RangeFrom::from(0.0..).contains(&0.5));
assert!(!RangeFrom::from(0.0..).contains(&f32::NAN));
assert!(!RangeFrom::from(f32::NAN..).contains(&0.5));