ConvertError

Enum ConvertError 

pub enum ConvertError {
Show 23 variants Read(Error), Write(Error), UnsupportedAttributeValue, InvalidAttributeValue, InvalidDebugInfoOffset, InvalidAddress, UnsupportedLineInstruction, UnsupportedLineStringForm, MissingLineEndSequence, MissingCompilationName, MissingCompilationDirectory, InvalidFileIndex, InvalidDirectoryIndex, InvalidLineBase, InvalidLineRef, InvalidUnitRef, InvalidDebugInfoRef, InvalidRangeRelativeAddress, UnsupportedCfiInstruction, UnsupportedIndirectAddress, UnsupportedOperation, InvalidBranchTarget, UnsupportedUnitType,
}
An error that occurred when converting a read value into a write value.

Variants



Read(Error)

An error occurred when reading.



Write(Error)

An error occurred when writing.



UnsupportedAttributeValue

Writing of this attribute value is not implemented yet.



InvalidAttributeValue

This attribute value is an invalid name/form combination.



InvalidDebugInfoOffset

A .debug_info reference does not refer to a valid entry.



InvalidAddress

An address could not be converted.



UnsupportedLineInstruction

Writing this line number instruction is not implemented yet.



UnsupportedLineStringForm

Writing this form of line string is not implemented yet.



MissingLineEndSequence

A DW_LNE_end_sequence instruction was missing at the end of a sequence.



MissingCompilationName

The name of the compilation unit is missing.



MissingCompilationDirectory

The path of the compilation directory is missing.



InvalidFileIndex

A .debug_line file index is invalid.



InvalidDirectoryIndex

A .debug_line directory index is invalid.



InvalidLineBase

A .debug_line line base is invalid.



InvalidLineRef

A .debug_line reference is invalid.



InvalidUnitRef

A .debug_info unit entry reference is invalid.



InvalidDebugInfoRef

A .debug_info reference is invalid.



InvalidRangeRelativeAddress

Invalid relative address in a range list.



UnsupportedCfiInstruction

Writing this CFI instruction is not implemented yet.



UnsupportedIndirectAddress

Writing indirect pointers is not implemented yet.



UnsupportedOperation

Writing this expression operation is not implemented yet.



InvalidBranchTarget

Operation branch target is invalid.



UnsupportedUnitType

Writing this unit type is not supported yet.