C-style plugin interface.
RSSN Plugin System
Defines the core traits and data structures for the rssn plugin architecture.
Structs
- Plugin
Error - A specialized error type for plugin-related failures.
Enums
- Plugin
Error Kind - Represents the kind of error that a plugin can encounter.
- Plugin
Health - Represents the health status of a plugin.
Traits
- Plugin
- The central trait that all
rssnplugins must implement.