pub struct LinearProgramState<P, F> {Show 16 fields
pub param: Option<P>,
pub prev_param: Option<P>,
pub best_param: Option<P>,
pub prev_best_param: Option<P>,
pub cost: F,
pub prev_cost: F,
pub best_cost: F,
pub prev_best_cost: F,
pub target_cost: F,
pub iter: u64,
pub last_best_iter: u64,
pub max_iters: u64,
pub counts: HashMap<String, u64>,
pub counting_enabled: bool,
pub time: Option<Duration>,
pub termination_status: TerminationStatus,
}Expand description
Maintains the state from iteration to iteration of a solver
This struct is passed from one iteration of an algorithm to the next.
Keeps track of
- parameter vector of current and previous iteration
- best parameter vector of current and previous iteration
- cost function value of current and previous iteration
- current and previous best cost function value
- target cost function value
- current iteration number
- iteration number where the last best parameter vector was found
- maximum number of iterations that will be executed
- problem function evaluation counts (cost function, gradient, jacobian, hessian,
- elapsed time
- termination status
Fields
param: Option<P>Current parameter vector
prev_param: Option<P>Previous parameter vector
best_param: Option<P>Current best parameter vector
prev_best_param: Option<P>Previous best parameter vector
cost: FCurrent cost function value
prev_cost: FPrevious cost function value
best_cost: FCurrent best cost function value
prev_best_cost: FPrevious best cost function value
target_cost: FTarget cost function value
iter: u64Current iteration
last_best_iter: u64Iteration number of last best cost
max_iters: u64Maximum number of iterations
counts: HashMap<String, u64>Evaluation counts
counting_enabled: boolUpdate evaluation counts?
time: Option<Duration>Time required so far
termination_status: TerminationStatusStatus of optimization execution
Implementations
Sourceimpl<P, F> LinearProgramState<P, F>
impl<P, F> LinearProgramState<P, F>
Sourcepub fn param(self, param: P) -> LinearProgramState<P, F>
pub fn param(self, param: P) -> LinearProgramState<P, F>
Set parameter vector. This shifts the stored parameter vector to the previous parameter vector.
Example
let state = state.param(param);Sourcepub fn target_cost(self, target_cost: F) -> LinearProgramState<P, F>
pub fn target_cost(self, target_cost: F) -> LinearProgramState<P, F>
Set target cost.
When this cost is reached, the algorithm will stop. The default is
Self::Float::NEG_INFINITY.
Example
let state = state.target_cost(0.0);Sourcepub fn max_iters(self, iters: u64) -> LinearProgramState<P, F>
pub fn max_iters(self, iters: u64) -> LinearProgramState<P, F>
Sourcepub fn cost(self, cost: F) -> LinearProgramState<P, F>
pub fn cost(self, cost: F) -> LinearProgramState<P, F>
Set the current cost function value. This shifts the stored cost function value to the previous cost function value.
Example
let state = state.cost(cost);Sourcepub fn counting(self, mode: bool) -> LinearProgramState<P, F>
pub fn counting(self, mode: bool) -> LinearProgramState<P, F>
Overrides state of counting function executions (default: false)
let state = state.counting(true);Trait Implementations
Sourceimpl<P, F> Clone for LinearProgramState<P, F>
impl<P, F> Clone for LinearProgramState<P, F>
Sourcefn clone(&self) -> LinearProgramState<P, F>
fn clone(&self) -> LinearProgramState<P, F>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<P, F> Debug for LinearProgramState<P, F>
impl<P, F> Debug for LinearProgramState<P, F>
Sourceimpl<'de, P, F> Deserialize<'de> for LinearProgramState<P, F>where
P: Deserialize<'de>,
F: Deserialize<'de>,
impl<'de, P, F> Deserialize<'de> for LinearProgramState<P, F>where
P: Deserialize<'de>,
F: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LinearProgramState<P, F>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LinearProgramState<P, F>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl<P, F> Serialize for LinearProgramState<P, F>
impl<P, F> Serialize for LinearProgramState<P, F>
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Sourceimpl<P, F> State for LinearProgramState<P, F>where
P: Clone,
F: ArgminFloat,
impl<P, F> State for LinearProgramState<P, F>where
P: Clone,
F: ArgminFloat,
Sourcefn new() -> LinearProgramState<P, F>
fn new() -> LinearProgramState<P, F>
Create new LinearProgramState instance
Example
use argmin::core::{LinearProgramState, State};
let state: LinearProgramState<Vec<f64>, f64> = LinearProgramState::new();
Sourcefn update(&mut self)
fn update(&mut self)
Checks if the current parameter vector is better than the previous best parameter value. If a new best parameter vector was found, the state is updated accordingly.
Example
let mut state: LinearProgramState<Vec<f64>, f64> = LinearProgramState::new();
// Simulating a new, better parameter vector
state.best_param = Some(vec![1.0f64]);
state.best_cost = 10.0;
state.param = Some(vec![2.0f64]);
state.cost = 5.0;
// Calling update
state.update();
// Check if update was successful
assert_eq!(state.best_param.as_ref().unwrap()[0], 2.0f64);
assert_eq!(state.best_cost.to_ne_bytes(), state.best_cost.to_ne_bytes());
assert!(state.is_best());For algorithms which do not compute the cost function, every new parameter vector will be the new best:
let mut state: LinearProgramState<Vec<f64>, f64> = LinearProgramState::new();
// Simulating a new, better parameter vector
state.best_param = Some(vec![1.0f64]);
state.param = Some(vec![2.0f64]);
// Calling update
state.update();
// Check if update was successful
assert_eq!(state.best_param.as_ref().unwrap()[0], 2.0f64);
assert_eq!(state.best_cost.to_ne_bytes(), state.best_cost.to_ne_bytes());
assert!(state.is_best());Sourcefn get_param(&self) -> Option<&P>
fn get_param(&self) -> Option<&P>
Returns a reference to the current parameter vector
Example
let param = state.get_param(); // Option<&P>Sourcefn get_best_param(&self) -> Option<&P>
fn get_best_param(&self) -> Option<&P>
Returns a reference to the current best parameter vector
Example
let best_param = state.get_best_param(); // Option<&P>Sourcefn terminate_with(self, reason: TerminationReason) -> LinearProgramState<P, F>
fn terminate_with(self, reason: TerminationReason) -> LinearProgramState<P, F>
Sets the termination status to Terminated with the given reason
Example
let state = state.terminate_with(TerminationReason::MaxItersReached);Sourcefn get_best_cost(&self) -> <LinearProgramState<P, F> as State>::Float
fn get_best_cost(&self) -> <LinearProgramState<P, F> as State>::Float
Sourcefn get_target_cost(&self) -> <LinearProgramState<P, F> as State>::Float
fn get_target_cost(&self) -> <LinearProgramState<P, F> as State>::Float
Sourcefn get_last_best_iter(&self) -> u64
fn get_last_best_iter(&self) -> u64
Returns iteration number of last best parameter vector.
Example
let last_best_iter = state.get_last_best_iter();Sourcefn get_max_iters(&self) -> u64
fn get_max_iters(&self) -> u64
Sourcefn get_termination_status(&self) -> &TerminationStatus
fn get_termination_status(&self) -> &TerminationStatus
Sourcefn get_termination_reason(&self) -> Option<&TerminationReason>
fn get_termination_reason(&self) -> Option<&TerminationReason>
Returns the termination reason if terminated, otherwise None.
Example
let termination_reason = state.get_termination_reason();Sourcefn increment_iter(&mut self)
fn increment_iter(&mut self)
Sourcefn func_counts<O>(&mut self, problem: &Problem<O>)
fn func_counts<O>(&mut self, problem: &Problem<O>)
Set all function evaluation counts to the evaluation counts of another Problem.
state.func_counts(&problem);Sourcefn is_best(&self) -> bool
fn is_best(&self) -> bool
Returns whether the current parameter vector is also the best parameter vector found so far.
Example
let is_best = state.is_best();Sourcefn terminated(&self) -> bool
fn terminated(&self) -> bool