pub struct RangeFrom<Idx> {
pub start: Idx,
}Expand description
A range only bounded inclusively below.
The RangeFrom contains all values with x >= start.
Note: Overflow in the IntoIterator implementation (when the contained
data type reaches its numerical limit) is allowed to panic, wrap, or
saturate. This behavior is defined by the implementation of the Step
trait. For primitive integers, this follows the normal rules, and respects
the overflow checks profile (panic in debug, wrap in release). Unlike
its legacy counterpart, the iterator will only panic after yielding the
maximum value when overflow checks are enabled.
Examples
use core::range::RangeFrom;
assert_eq!(RangeFrom::from(2..), core::range::RangeFrom { start: 2 });
assert_eq!(2 + 3 + 4, RangeFrom::from(2..).into_iter().take(3).sum());Edition notes
It is planned that the syntax start.. will construct this
type in a future edition, but it does not do so today.
Fields
start: IdxThe lower bound of the range (inclusive).
Implementations
Sourceimpl<Idx> RangeFrom<Idx>where
Idx: Step,
impl<Idx> RangeFrom<Idx>where
Idx: Step,
1.96.0 · Sourcepub fn iter(&self) -> RangeFromIter<Idx> ⓘ
pub fn iter(&self) -> RangeFromIter<Idx> ⓘ
Creates an iterator over the elements within this range.
Shorthand for .clone().into_iter()
Examples
use core::range::RangeFrom;
let mut i = RangeFrom::from(3..).iter().map(|n| n*n);
assert_eq!(i.next(), Some(9));
assert_eq!(i.next(), Some(16));
assert_eq!(i.next(), Some(25));Sourceimpl<Idx> RangeFrom<Idx>where
Idx: PartialOrd,
impl<Idx> RangeFrom<Idx>where
Idx: PartialOrd,
1.96.0 (const: unstable) · Sourcepub fn contains<U>(&self, item: &U) -> bool
pub fn contains<U>(&self, item: &U) -> bool
Returns true if item is contained in the range.
Examples
use core::range::RangeFrom;
assert!(!RangeFrom::from(3..).contains(&2));
assert!( RangeFrom::from(3..).contains(&3));
assert!( RangeFrom::from(3..).contains(&1_000_000_000));
assert!( RangeFrom::from(0.0..).contains(&0.5));
assert!(!RangeFrom::from(0.0..).contains(&f32::NAN));
assert!(!RangeFrom::from(f32::NAN..).contains(&0.5));Trait Implementations
impl<Idx> Copy for RangeFrom<Idx>where
Idx: Copy,
impl<Idx> Eq for RangeFrom<Idx>where
Idx: Eq,
Sourceimpl<T> IntoBounds<T> for RangeFrom<T>
impl<T> IntoBounds<T> for RangeFrom<T>
1.96.0 · Sourceimpl<A> IntoIterator for RangeFrom<A>where
A: Step,
impl<A> IntoIterator for RangeFrom<A>where
A: Step,
Sourceimpl<T> OneSidedRange<T> for RangeFrom<T>where
RangeFrom<T>: RangeBounds<T>,
impl<T> OneSidedRange<T> for RangeFrom<T>where
RangeFrom<T>: RangeBounds<T>,
Sourcefn bound(self) -> (OneSidedRangeBound, T)
fn bound(self) -> (OneSidedRangeBound, T)
one_sided_range)split_off and
split_off_mut that returns the bound of the one-sided range.1.96.0 (const: unstable) · Sourceimpl<Idx> PartialEq for RangeFrom<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for RangeFrom<Idx>where
Idx: PartialEq,
1.96.0 (const: unstable) · Sourceimpl<T> RangeBounds<T> for RangeFrom<T>
impl<T> RangeBounds<T> for RangeFrom<T>
1.96.0 (const: unstable) · Sourceimpl<T> RangeBounds<T> for RangeFrom<&T>
If you need to use this implementation where T is unsized,
consider using the RangeBounds impl for a 2-tuple of Bound<&T>,
i.e. replace start.. with (Bound::Included(start), Bound::Unbounded).
impl<T> RangeBounds<T> for RangeFrom<&T>
If you need to use this implementation where T is unsized,
consider using the RangeBounds impl for a 2-tuple of Bound<&T>,
i.e. replace start.. with (Bound::Included(start), Bound::Unbounded).
Sourceimpl SliceIndex<ByteStr> for RangeFrom<usize>
impl SliceIndex<ByteStr> for RangeFrom<usize>
Sourcefn get(
self,
slice: &ByteStr,
) -> Option<&<RangeFrom<usize> as SliceIndex<ByteStr>>::Output>
fn get( self, slice: &ByteStr, ) -> Option<&<RangeFrom<usize> as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut ByteStr,
) -> Option<&mut <RangeFrom<usize> as SliceIndex<ByteStr>>::Output>
fn get_mut( self, slice: &mut ByteStr, ) -> Option<&mut <RangeFrom<usize> as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const ByteStr,
) -> *const <RangeFrom<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked( self, slice: *const ByteStr, ) -> *const <RangeFrom<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut ByteStr,
) -> *mut <RangeFrom<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut ByteStr, ) -> *mut <RangeFrom<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)1.96.0 (const: unstable) · Sourceimpl<T> SliceIndex<[T]> for RangeFrom<usize>
impl<T> SliceIndex<[T]> for RangeFrom<usize>
Sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)Sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)Sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)1.96.0 (const: unstable) · Sourceimpl SliceIndex<str> for RangeFrom<usize>
impl SliceIndex<str> for RangeFrom<usize>
Sourcefn get(
self,
slice: &str,
) -> Option<&<RangeFrom<usize> as SliceIndex<str>>::Output>
fn get( self, slice: &str, ) -> Option<&<RangeFrom<usize> as SliceIndex<str>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut str,
) -> Option<&mut <RangeFrom<usize> as SliceIndex<str>>::Output>
fn get_mut( self, slice: &mut str, ) -> Option<&mut <RangeFrom<usize> as SliceIndex<str>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const str,
) -> *const <RangeFrom<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked( self, slice: *const str, ) -> *const <RangeFrom<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str,
) -> *mut <RangeFrom<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut str, ) -> *mut <RangeFrom<usize> as SliceIndex<str>>::Output
slice_index_methods)impl<Idx> StructuralPartialEq for RangeFrom<Idx>where
Idx: PartialEq,